@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Exception::Reporter;
 # ABSTRACT: a generic exception-reporting object
-$Exception::Reporter::VERSION = '0.013';
+$Exception::Reporter::VERSION = '0.014';
 #pod =head1 SYNOPSIS
 #pod
 #pod B<Achtung!>  This is an experimental refactoring of some long-standing internal
@@ -203,10 +203,41 @@ sub report_exception {
   my @caller = caller( $self->{caller_level} );
   $arg->{reporter} ||= $caller[0];
 
-  my @summaries;
+  my $summaries = $self->collect_summaries($dumpables);
+
+  for my $sender ($self->_senders) {
+    $sender->send_report(
+      $summaries,
+      $arg,
+      {
+        guid   => $guid,
+        caller => \@caller,
+      }
+    );
+  }
+
+  return $guid;
+}
+
+#pod =method collect_summaries
+#pod
+#pod   $reporter->report_exception(\@dumpables);
+#pod
+#pod This method is used by L</report_exception> to convert dumpables into
+#pod summaries. It may be called directly by summarizers through
+#pod C<< $self->reporter->collect_summaries(\@dumpables); >> if your
+#pod summarizers receive dumpables that may be handled by another summarizer. Be
+#pod wary though, because you could possibly create an endless loop...
+#pod
+#pod =cut
+
+sub collect_summaries {
+  my ($self, $dumpables) = @_;
 
   my @sumz = $self->_summarizers;
 
+  my @summaries;
+
   DUMPABLE: for my $dumpable (
     @$dumpables,
     map {; [ $_, $self->{always_dump}{$_}->() ] }
@@ -229,18 +260,7 @@ sub report_exception {
     ];
   }
 
-  for my $sender ($self->_senders) {
-    $sender->send_report(
-      \@summaries,
-      $arg,
-      {
-        guid   => $guid,
-        caller => \@caller,
-      }
-    );
-  }
-
-  return $guid;
+  return \@summaries;
 }
 
 1;
@@ -257,7 +277,7 @@ Exception::Reporter - a generic exception-reporting object
 
 =head1 VERSION
 
-version 0.013
+version 0.014
 
 =head1 SYNOPSIS
 
@@ -396,16 +416,36 @@ placeholder is put in its place.
 The arrayref constructed is passed to the C<send_report> method of each sender,
 in turn.
 
+=head2 collect_summaries
+
+  $reporter->report_exception(\@dumpables);
+
+This method is used by L</report_exception> to convert dumpables into
+summaries. It may be called directly by summarizers through
+C<< $self->reporter->collect_summaries(\@dumpables); >> if your
+summarizers receive dumpables that may be handled by another summarizer. Be
+wary though, because you could possibly create an endless loop...
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@cpan.org>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Tomohiro Hosaka
+=for stopwords Matthew Horsfall Tomohiro Hosaka
+
+=over 4
+
+=item *
+
+Matthew Horsfall <wolfsage@gmail.com>
+
+=item *
 
 Tomohiro Hosaka <bokutin@bokut.in>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by Ricardo Signes.
